@@ -247,7 +247,7 @@ class MeasurementTree:
         # iterate over metadata to innermost data to get names of all dimensions
         for i in range(len(data_shape)):
             coord_name = self.get_metadata(self.target[row][0])['name'][i]
-            if coord_name in coords:
+            while coord_name in coords.keys():
                 coord_name = coord_name+'+'
             coords[coord_name] = self.get_scales(self.target[row][0], i)
             dims.append(coord_name)
